<?php
//============================================================+
// File name   : cp_ec_pdf_doc.php                             
// Begin       : 2002-07-27                                    
// Last Update : 2004-07-15                                    
//                                                             
// Description : FPDF class extension                          
//                                                             
//
// Author: Nicola Asuni
//
// (c) Copyright:
//               Tecnick.com S.r.l.
//               Via Ugo Foscolo n.19
//               09045 Quartu Sant'Elena (CA)
//               ITALY
//               www.tecnick.com
//               info@tecnick.com
//
// License: GNU GENERAL PUBLIC LICENSE v.2
//          http://www.gnu.org/copyleft/gpl.html
//============================================================+

require_once('../../shared/pdf/tcpdf.php');

/**
 * AIOCP FPDF class extension for commercial documents
 * @name EC_DOC_PDF
 * @package FPDF
 * @version 1.0
 * @author Nicola Asuni
*/
class EC_DOC_PDF extends TCPDF {
	
	/**
	 * company data
	 */
	var $company_data;

	/**
	 * This is the class constructor. 
	 * It allows to set up the page format, the orientation and 
	 * the measure unit used in all the methods (except for the font sizes).
	 * @since 1.0
	 * @param string $orientation page orientation. Possible values are (case insensitive):<ul><li>P or Portrait (default)</li><li>L or Landscape</li></ul>
	 * @param string $unit User measure unit. Possible values are:<ul><li>pt: point</li><li>mm: millimeter (default)</li><li>cm: centimeter</li><li>in: inch</li></ul><br />A point equals 1/72 of inch, that is to say about 0.35 mm (an inch being 2.54 cm). This is a very common unit in typography; font sizes are expressed in that unit.
	 * @param mixed $format The format used for pages. It can be either one of the following values (case insensitive) or a custom format in the form of a two-element array containing the width and the height (expressed in the unit given by unit).<ul><li>4A0</li><li>2A0</li><li>A0</li><li>A1</li><li>A2</li><li>A3</li><li>A4 (default)</li><li>A5</li><li>A6</li><li>A7</li><li>A8</li><li>A9</li><li>A10</li><li>B0</li><li>B1</li><li>B2</li><li>B3</li><li>B4</li><li>B5</li><li>B6</li><li>B7</li><li>B8</li><li>B9</li><li>B10</li><li>C0</li><li>C1</li><li>C2</li><li>C3</li><li>C4</li><li>C5</li><li>C6</li><li>C7</li><li>C8</li><li>C9</li><li>C10</li><li>RA0</li><li>RA1</li><li>RA2</li><li>RA3</li><li>RA4</li><li>SRA0</li><li>SRA1</li><li>SRA2</li><li>SRA3</li><li>SRA4</li><li>LETTER</li><li>LEGAL</li><li>EXECUTIVE</li><li>FOLIO</li></ul>
	 * @author Clment Lavoillotte
	 */
	function EC_DOC_PDF($orientation='P', $unit='mm', $format='A4', $unicode=false, $encoding="ISO-8859-15") {
		//Call parent constructor
		$this->TCPDF($orientation, $unit, $format, $unicode, $encoding);
		
		//Initialization
		$this->b = 0;
		$this->i = 0;
		$this->u = 0;
		$this->HREF = '';
		$this->fontlist = array("arial", "times", "courier", "helvetica", "symbol");
		$this->issetfont = false;
		$this->issetcolor = false;
		
		$this->tableborder = 0;
		$this->tdbegin = false;
		$this->tdwidth=  0;
		$this->tdheight = 0;
		$this->tdalign = "L";
		$this->tdbgcolor = false;
	}
	
		/**
 	 * This method is used to render the page header
	 */
	function Header() {
		if ($this->print_header) {
			$header_string = "";
			
			if ($this->company_data['fiscalcode']) {
				 $header_string .= $this->lang_templates['w_fiscalcode'].": ".$this->company_data['fiscalcode']."";
			}
			
			if ($this->company_data['address']) {
				 $header_string .= " - ".$this->company_data['address'];
			}
			if ($this->company_data['postcode']) {
				 $header_string .= " - ".$this->company_data['postcode'];
			}
			if ($this->company_data['city']) {
				 $header_string .= " - ".$this->company_data['city'];
			}
			if ($this->company_data['state']) {
				 $header_string .= " (".$this->company_data['state'].")";
			}
			if ($this->company_data['country']) {
				 $header_string .= " - ".strtoupper($this->company_data['country']);
			}
			
			if ($this->company_data['telephone']) {
				 $header_string .= " - ".$this->lang_templates['w_telephone_abbr']." ".$this->company_data['telephone'];
			}
			if ($this->company_data['fax']) {
				 $header_string .= " - ".$this->lang_templates['w_fax']." ".$this->company_data['fax'];
			}
			
			if ($this->company_data['url']) {
				 $header_string .= " - ".$this->company_data['url'];
			}
			if ($this->company_data['email']) {
				 $header_string .= " - ".$this->company_data['email'];
			}
			
			//set current position
			$this->SetXY($this->lMargin, $this->header_margin);
			
			if (($this->company_data['logo']) AND ($this->company_data['logo'] != K_BLANK_IMAGE)) {
				$this->Image(K_PATH_IMAGES_COMPANY.$this->company_data['logo'], $this->lMargin, $this->header_margin, $this->company_data['logowidth']);
			}
			else {
				$this->img_rb_y = $this->GetY();
			}
			
			$cell_height = round((K_CELL_HEIGHT_RATIO * $this->header_font[2]) / $this->k, 2);
			
			$header_x = $this->lMargin + ($this->company_data['logowidth'] * 1.05); //set left margin for text data cell
			
			$this->SetFont($this->header_font[0], 'B', $this->header_font[2]);
			$this->SetX($header_x);
			$this->Cell($this->header_width, $cell_height, $this->company_data['name'], 0, 1, 'L'); 
			
			$this->SetFont($this->header_font[0], $this->header_font[1], $this->header_font[2]);
			$this->SetX($header_x);
			$this->MultiCell($this->header_width, $cell_height, $header_string, 0, 'L', 0);
			
			if (!$this->header_width) {
				//set style for cell border
				$this->SetLineWidth(0.3);
				$this->SetDrawColor(0, 0, 0);
				$this->SetY(max($this->img_rb_y, $this->GetY()));
				$this->Cell(0, 0, '', 'T', 0, 'C'); 
			}
			
			//restore margin position
			$this->SetXY($this->lMargin, $this->tMargin);
		}
	}
	
	/**
 	 * This method is used to render the page footer.
	 */
	function Footer() {
		
		if ($this->print_footer) {
			//$this->company_data['description']
			//$this->company_data['otherdata']
			
			//set font
			$this->SetFont($this->footer_font[0], $this->footer_font[1] , $this->footer_font[2]);
			//set style for cell border
			$line_width = 0.3;
			$this->SetLineWidth($line_width);
			$this->SetDrawColor(0, 0, 0);
			
			$footer_height = round((K_CELL_HEIGHT_RATIO * $this->footer_font[2]) / $this->k, 2); //footer height
			//get footer y position
			$footer_y = $this->h - $this->footer_margin - $footer_height;
			//set current position
			$this->SetXY($this->lMargin, $footer_y); 
			
			//print document barcode
			if ($this->barcode) {
				$this->Ln();
				$barcode_width = round(($this->w - $this->lMargin - $this->rMargin)); //max width
				$this->Barcode($this->lMargin, $footer_y + $line_width, $barcode_width, $footer_height - $line_width, "C128B", false, false, 2, $this->barcode);
			}
			
			$this->SetXY($this->lMargin, $footer_y); 
			
			//Print page number
			$this->Cell(0, $footer_height, $this->lang_templates['w_page']." ".$this->PageNo().' / {nb}', 'T', 0, 'R'); 
		}
	}
	
	function Barcode($x, $y, $w, $h, $type, $style, $font, $xres, $code) {
		$this->writeBarcode($x, $y, $w, $h, $type, $style, $font, $xres, $code);
	}
	
} // END OF CLASS

//============================================================+
// END OF FILE                                                 
//============================================================+
?>